@@ -28,18 +28,13 @@
 
 
 ****************************************************************************/
-#ifndef _P_Thread_h_
-#define _P_Thread_h_
+#pragma once
 
 #include "I_Thread.h"
 
 ///////////////////////////////////////////////
 // Common Interface impl                     //
 ///////////////////////////////////////////////
-TS_INLINE
-Thread::~Thread()
-{
-}
 
 TS_INLINE void
 Thread::set_specific()
@@ -52,5 +47,3 @@ this_thread()
 {
   return (Thread *)ink_thread_getspecific(Thread::thread_data_key);
 }
-
-#endif //_P_Thread_h_
