@@ -19,16 +19,12 @@
   limitations under the License.
  */
 
-#include "ts/ink_config.h"
+#include "tscore/ink_config.h"
 #include "P_Net.h"
 
-SSLNetAccept::SSLNetAccept(const NetProcessor::AcceptOptions &opt) : NetAccept(opt)
-{
-}
+SSLNetAccept::SSLNetAccept(const NetProcessor::AcceptOptions &opt) : NetAccept(opt) {}
 
-SSLNetAccept::~SSLNetAccept()
-{
-}
+SSLNetAccept::~SSLNetAccept() {}
 
 NetProcessor *
 SSLNetAccept::getNetProcessor() const
