@@ -21,8 +21,7 @@
  *  limitations under the License.
  */
 
-#ifndef BALANCER_H_29177589_32F1_4D93_AE4F_1E140EDCC273
-#define BALANCER_H_29177589_32F1_4D93_AE4F_1E140EDCC273
+#pragma once
 
 #include <ts/ts.h>
 #include <ts/remap.h>
@@ -43,11 +42,9 @@ struct BalancerTarget {
 
 struct BalancerInstance {
   virtual ~BalancerInstance() {}
-  virtual void push_target(const BalancerTarget &) = 0;
+  virtual void push_target(const BalancerTarget &)                       = 0;
   virtual const BalancerTarget &balance(TSHttpTxn, TSRemapRequestInfo *) = 0;
 };
 
 BalancerInstance *MakeHashBalancer(const char *);
 BalancerInstance *MakeRoundRobinBalancer(const char *);
-
-#endif /* BALANCER_H_29177589_32F1_4D93_AE4F_1E140EDCC273 */
