@@ -72,10 +72,10 @@ ProxyClientTransaction::release(IOBufferReader *r)
   }
 }
 
-void
+bool
 ProxyClientTransaction::attach_server_session(HttpServerSession *ssession, bool transaction_done)
 {
-  parent->attach_server_session(ssession, transaction_done);
+  return parent->attach_server_session(ssession, transaction_done);
 }
 
 void
@@ -127,3 +127,9 @@ ProxyClientTransaction::get_transaction_priority_dependence() const
 {
   return 0;
 }
+
+bool
+ProxyClientTransaction::has_request_body(int64_t request_content_length, bool is_chunked) const
+{
+  return request_content_length > 0 || is_chunked;
+}
