@@ -45,7 +45,7 @@
   -------------------------------------------------------------------------*/
 
 ParseResult
-HTTPHdr::parse_req(HTTPParser *parser, IOBufferReader *r, int *bytes_used, bool eof, bool strict_uri_parsing)
+HTTPHdr::parse_req(HTTPParser *parser, IOBufferReader *r, int *bytes_used, bool eof, int strict_uri_parsing)
 {
   const char *start;
   const char *tmp;
@@ -100,13 +100,21 @@ HTTPHdr::parse_resp(HTTPParser *parser, IOBufferReader *r, int *bytes_used, bool
 
   do {
     int64_t b_avail = r->block_read_avail();
+    tmp = start = r->start();
 
-    if (b_avail <= 0 && eof == false) {
-      break;
+    // No data currently available.
+    if (b_avail <= 0) {
+      if (eof == false) { // more data may arrive later, return CONTINUE state.
+        break;
+      } else if (nullptr == start) {
+        // EOF on empty MIOBuffer - that's a fail, don't bother with parsing.
+        // (otherwise will attempt to attach_block a non-existent block)
+        state = PARSE_RESULT_ERROR;
+        break;
+      }
     }
 
-    tmp = start = r->start();
-    end         = start + b_avail;
+    end = start + b_avail;
 
     int heap_slot = m_heap->attach_block(r->get_current_block(), start);
 
