@@ -466,8 +466,8 @@ HttpDebugNames::get_api_hook_name(TSHttpHookID t)
     return "TS_SSL_CERT_HOOK";
   case TS_SSL_SERVERNAME_HOOK:
     return "TS_SSL_SERVERNAME_HOOK";
-  case TS_SSL_SERVER_VERIFY_HOOK:
-    return "TS_SSL_SERVER_VERIFY_HOOK";
+  case TS_SSL_VERIFY_SERVER_HOOK:
+    return "TS_SSL_VERIFY_SERVER_HOOK";
   case TS_SSL_VERIFY_CLIENT_HOOK:
     return "TS_SSL_VERIFY_CLIENT_HOOK";
   case TS_SSL_SESSION_HOOK:
