@@ -23,7 +23,7 @@
 
 #include "HPACK.h"
 #include "HuffmanCodec.h"
-#include "ts/TestBox.h"
+#include "tscore/TestBox.h"
 
 // Constants for regression test
 const static int DYNAMIC_TABLE_SIZE_FOR_REGRESSION_TEST = 256;
@@ -41,33 +41,6 @@ const static int MAX_TABLE_SIZE                         = 4096;
  *                                                                                 *
  ***********************************************************************************/
 
-// [RFC 7541] C.1. Integer Representation Examples
-const static struct {
-  uint32_t raw_integer;
-  uint8_t *encoded_field;
-  int encoded_field_len;
-  int prefix;
-} integer_test_case[] = {{10, (uint8_t *)"\x0A", 1, 5}, {1337, (uint8_t *)"\x1F\x9A\x0A", 3, 5}, {42, (uint8_t *)"\x2A", 1, 8}};
-
-// Example: custom-key: custom-header
-const static struct {
-  char *raw_string;
-  uint32_t raw_string_len;
-  uint8_t *encoded_field;
-  int encoded_field_len;
-} string_test_case[] = {{(char *)"", 0, (uint8_t *)"\x0"
-                                                   "",
-                         1},
-                        {(char *)"custom-key", 10, (uint8_t *)"\xA"
-                                                              "custom-key",
-                         11},
-                        {(char *)"", 0, (uint8_t *)"\x80"
-                                                   "",
-                         1},
-                        {(char *)"custom-key", 10, (uint8_t *)"\x88"
-                                                              "\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f",
-                         9}};
-
 // [RFC 7541] C.2.4. Indexed Header Field
 const static struct {
   int index;
@@ -82,81 +55,94 @@ const static struct {
   char *raw_name;
   char *raw_value;
   int index;
-  HpackFieldType type;
+  HpackField type;
   uint8_t *encoded_field;
   int encoded_field_len;
-} literal_test_case[] = {
-  {(char *)"custom-key", (char *)"custom-header", 0, HPACK_FIELD_INDEXED_LITERAL, (uint8_t *)"\x40\x0a"
-                                                                                             "custom-key\x0d"
-                                                                                             "custom-header",
-   26},
-  {(char *)"custom-key", (char *)"custom-header", 0, HPACK_FIELD_NOINDEX_LITERAL, (uint8_t *)"\x00\x0a"
-                                                                                             "custom-key\x0d"
-                                                                                             "custom-header",
-   26},
-  {(char *)"custom-key", (char *)"custom-header", 0, HPACK_FIELD_NEVERINDEX_LITERAL, (uint8_t *)"\x10\x0a"
-                                                                                                "custom-key\x0d"
-                                                                                                "custom-header",
-   26},
-  {(char *)":path", (char *)"/sample/path", 4, HPACK_FIELD_INDEXED_LITERAL, (uint8_t *)"\x44\x0c"
-                                                                                       "/sample/path",
-   14},
-  {(char *)":path", (char *)"/sample/path", 4, HPACK_FIELD_NOINDEX_LITERAL, (uint8_t *)"\x04\x0c"
-                                                                                       "/sample/path",
-   14},
-  {(char *)":path", (char *)"/sample/path", 4, HPACK_FIELD_NEVERINDEX_LITERAL, (uint8_t *)"\x14\x0c"
-                                                                                          "/sample/path",
-   14},
-  {(char *)"password", (char *)"secret", 0, HPACK_FIELD_INDEXED_LITERAL, (uint8_t *)"\x40\x08"
-                                                                                    "password\x06"
-                                                                                    "secret",
-   17},
-  {(char *)"password", (char *)"secret", 0, HPACK_FIELD_NOINDEX_LITERAL, (uint8_t *)"\x00\x08"
-                                                                                    "password\x06"
-                                                                                    "secret",
-   17},
-  {(char *)"password", (char *)"secret", 0, HPACK_FIELD_NEVERINDEX_LITERAL, (uint8_t *)"\x10\x08"
-                                                                                       "password\x06"
-                                                                                       "secret",
-   17},
-  // with Huffman Coding
-  {(char *)"custom-key", (char *)"custom-header", 0, HPACK_FIELD_INDEXED_LITERAL,
-   (uint8_t *)"\x40"
-              "\x88\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f"
-              "\x89\x25\xa8\x49\xe9\x5a\x72\x8e\x42\xd9",
-   20},
-  {(char *)"custom-key", (char *)"custom-header", 0, HPACK_FIELD_NOINDEX_LITERAL,
-   (uint8_t *)"\x00"
-              "\x88\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f"
-              "\x89\x25\xa8\x49\xe9\x5a\x72\x8e\x42\xd9",
-   20},
-  {(char *)"custom-key", (char *)"custom-header", 0, HPACK_FIELD_NEVERINDEX_LITERAL,
-   (uint8_t *)"\x10"
-              "\x88\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f"
-              "\x89\x25\xa8\x49\xe9\x5a\x72\x8e\x42\xd9",
-   20},
-  {(char *)":path", (char *)"/sample/path", 4, HPACK_FIELD_INDEXED_LITERAL, (uint8_t *)"\x44"
-                                                                                       "\x89\x61\x03\xa6\xba\x0a\xc5\x63\x4c\xff",
-   11},
-  {(char *)":path", (char *)"/sample/path", 4, HPACK_FIELD_NOINDEX_LITERAL, (uint8_t *)"\x04"
-                                                                                       "\x89\x61\x03\xa6\xba\x0a\xc5\x63\x4c\xff",
-   11},
-  {(char *)":path", (char *)"/sample/path", 4, HPACK_FIELD_NEVERINDEX_LITERAL,
-   (uint8_t *)"\x14"
-              "\x89\x61\x03\xa6\xba\x0a\xc5\x63\x4c\xff",
-   11},
-  {(char *)"password", (char *)"secret", 0, HPACK_FIELD_INDEXED_LITERAL, (uint8_t *)"\x40"
-                                                                                    "\x86\xac\x68\x47\x83\xd9\x27"
-                                                                                    "\x84\x41\x49\x61\x53",
-   13},
-  {(char *)"password", (char *)"secret", 0, HPACK_FIELD_NOINDEX_LITERAL, (uint8_t *)"\x00"
-                                                                                    "\x86\xac\x68\x47\x83\xd9\x27"
-                                                                                    "\x84\x41\x49\x61\x53",
-   13},
-  {(char *)"password", (char *)"secret", 0, HPACK_FIELD_NEVERINDEX_LITERAL, (uint8_t *)"\x10"
-                                                                                       "\x86\xac\x68\x47\x83\xd9\x27"
-                                                                                       "\x84\x41\x49\x61\x53",
-   13}};
+} literal_test_case[] = {{(char *)"custom-key", (char *)"custom-header", 0, HpackField::INDEXED_LITERAL,
+                          (uint8_t *)"\x40\x0a"
+                                     "custom-key\x0d"
+                                     "custom-header",
+                          26},
+                         {(char *)"custom-key", (char *)"custom-header", 0, HpackField::NOINDEX_LITERAL,
+                          (uint8_t *)"\x00\x0a"
+                                     "custom-key\x0d"
+                                     "custom-header",
+                          26},
+                         {(char *)"custom-key", (char *)"custom-header", 0, HpackField::NEVERINDEX_LITERAL,
+                          (uint8_t *)"\x10\x0a"
+                                     "custom-key\x0d"
+                                     "custom-header",
+                          26},
+                         {(char *)":path", (char *)"/sample/path", 4, HpackField::INDEXED_LITERAL,
+                          (uint8_t *)"\x44\x0c"
+                                     "/sample/path",
+                          14},
+                         {(char *)":path", (char *)"/sample/path", 4, HpackField::NOINDEX_LITERAL,
+                          (uint8_t *)"\x04\x0c"
+                                     "/sample/path",
+                          14},
+                         {(char *)":path", (char *)"/sample/path", 4, HpackField::NEVERINDEX_LITERAL,
+                          (uint8_t *)"\x14\x0c"
+                                     "/sample/path",
+                          14},
+                         {(char *)"password", (char *)"secret", 0, HpackField::INDEXED_LITERAL,
+                          (uint8_t *)"\x40\x08"
+                                     "password\x06"
+                                     "secret",
+                          17},
+                         {(char *)"password", (char *)"secret", 0, HpackField::NOINDEX_LITERAL,
+                          (uint8_t *)"\x00\x08"
+                                     "password\x06"
+                                     "secret",
+                          17},
+                         {(char *)"password", (char *)"secret", 0, HpackField::NEVERINDEX_LITERAL,
+                          (uint8_t *)"\x10\x08"
+                                     "password\x06"
+                                     "secret",
+                          17},
+                         // with Huffman Coding
+                         {(char *)"custom-key", (char *)"custom-header", 0, HpackField::INDEXED_LITERAL,
+                          (uint8_t *)"\x40"
+                                     "\x88\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f"
+                                     "\x89\x25\xa8\x49\xe9\x5a\x72\x8e\x42\xd9",
+                          20},
+                         {(char *)"custom-key", (char *)"custom-header", 0, HpackField::NOINDEX_LITERAL,
+                          (uint8_t *)"\x00"
+                                     "\x88\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f"
+                                     "\x89\x25\xa8\x49\xe9\x5a\x72\x8e\x42\xd9",
+                          20},
+                         {(char *)"custom-key", (char *)"custom-header", 0, HpackField::NEVERINDEX_LITERAL,
+                          (uint8_t *)"\x10"
+                                     "\x88\x25\xa8\x49\xe9\x5b\xa9\x7d\x7f"
+                                     "\x89\x25\xa8\x49\xe9\x5a\x72\x8e\x42\xd9",
+                          20},
+                         {(char *)":path", (char *)"/sample/path", 4, HpackField::INDEXED_LITERAL,
+                          (uint8_t *)"\x44"
+                                     "\x89\x61\x03\xa6\xba\x0a\xc5\x63\x4c\xff",
+                          11},
+                         {(char *)":path", (char *)"/sample/path", 4, HpackField::NOINDEX_LITERAL,
+                          (uint8_t *)"\x04"
+                                     "\x89\x61\x03\xa6\xba\x0a\xc5\x63\x4c\xff",
+                          11},
+                         {(char *)":path", (char *)"/sample/path", 4, HpackField::NEVERINDEX_LITERAL,
+                          (uint8_t *)"\x14"
+                                     "\x89\x61\x03\xa6\xba\x0a\xc5\x63\x4c\xff",
+                          11},
+                         {(char *)"password", (char *)"secret", 0, HpackField::INDEXED_LITERAL,
+                          (uint8_t *)"\x40"
+                                     "\x86\xac\x68\x47\x83\xd9\x27"
+                                     "\x84\x41\x49\x61\x53",
+                          13},
+                         {(char *)"password", (char *)"secret", 0, HpackField::NOINDEX_LITERAL,
+                          (uint8_t *)"\x00"
+                                     "\x86\xac\x68\x47\x83\xd9\x27"
+                                     "\x84\x41\x49\x61\x53",
+                          13},
+                         {(char *)"password", (char *)"secret", 0, HpackField::NEVERINDEX_LITERAL,
+                          (uint8_t *)"\x10"
+                                     "\x86\xac\x68\x47\x83\xd9\x27"
+                                     "\x84\x41\x49\x61\x53",
+                          13}};
 
 // [RFC 7541] C.3. Request Examples without Huffman Coding - C.3.1. First Request
 // [RFC 7541] C.4. Request Examples with Huffman Coding - C.4.1. First Request
@@ -300,42 +286,6 @@ const static struct {
  *                                                                                 *
  ***********************************************************************************/
 
-REGRESSION_TEST(HPACK_EncodeInteger)(RegressionTest *t, int, int *pstatus)
-{
-  TestBox box(t, pstatus);
-  box = REGRESSION_TEST_PASSED;
-  uint8_t buf[BUFSIZE_FOR_REGRESSION_TEST];
-
-  for (const auto &i : integer_test_case) {
-    memset(buf, 0, BUFSIZE_FOR_REGRESSION_TEST);
-
-    int len = encode_integer(buf, buf + BUFSIZE_FOR_REGRESSION_TEST, i.raw_integer, i.prefix);
-
-    box.check(len == i.encoded_field_len, "encoded length was %d, expecting %d", len, i.encoded_field_len);
-    box.check(len > 0 && memcmp(buf, i.encoded_field, len) == 0, "encoded value was invalid");
-  }
-}
-
-REGRESSION_TEST(HPACK_EncodeString)(RegressionTest *t, int, int *pstatus)
-{
-  TestBox box(t, pstatus);
-  box = REGRESSION_TEST_PASSED;
-
-  uint8_t buf[BUFSIZE_FOR_REGRESSION_TEST];
-  int len;
-
-  // FIXME Current encoder support only huffman conding.
-  for (unsigned int i = 2; i < sizeof(string_test_case) / sizeof(string_test_case[0]); i++) {
-    memset(buf, 0, BUFSIZE_FOR_REGRESSION_TEST);
-
-    len = encode_string(buf, buf + BUFSIZE_FOR_REGRESSION_TEST, string_test_case[i].raw_string, string_test_case[i].raw_string_len);
-
-    box.check(len == string_test_case[i].encoded_field_len, "encoded length was %d, expecting %d", len,
-              string_test_case[i].encoded_field_len);
-    box.check(len > 0 && memcmp(buf, string_test_case[i].encoded_field, len) == 0, "encoded string was invalid");
-  }
-}
-
 REGRESSION_TEST(HPACK_EncodeIndexedHeaderField)(RegressionTest *t, int, int *pstatus)
 {
   TestBox box(t, pstatus);
@@ -440,7 +390,7 @@ REGRESSION_TEST(HPACK_Encode)(RegressionTest *t, int, int *pstatus)
       }
 
       HpackLookupResult lookupResult = indexing_table.lookup(expected_name, expected_name_len, expected_value, expected_value_len);
-      box.check(lookupResult.match_type == HPACK_EXACT_MATCH && lookupResult.index_type == HPACK_INDEX_TYPE_DYNAMIC,
+      box.check(lookupResult.match_type == HpackMatch::EXACT && lookupResult.index_type == HpackIndex::DYNAMIC,
                 "the header field is not indexed");
 
       expected_dynamic_table_size += dynamic_table_response_test_case[i][j].size;
@@ -449,41 +399,6 @@ REGRESSION_TEST(HPACK_Encode)(RegressionTest *t, int, int *pstatus)
   }
 }
 
-REGRESSION_TEST(HPACK_DecodeInteger)(RegressionTest *t, int, int *pstatus)
-{
-  TestBox box(t, pstatus);
-  box = REGRESSION_TEST_PASSED;
-
-  uint32_t actual;
-
-  for (const auto &i : integer_test_case) {
-    int len = decode_integer(actual, i.encoded_field, i.encoded_field + i.encoded_field_len, i.prefix);
-
-    box.check(len == i.encoded_field_len, "decoded length was %d, expecting %d", len, i.encoded_field_len);
-    box.check(actual == i.raw_integer, "decoded value was %d, expected %d", actual, i.raw_integer);
-  }
-}
-
-REGRESSION_TEST(HPACK_DecodeString)(RegressionTest *t, int, int *pstatus)
-{
-  TestBox box(t, pstatus);
-  box = REGRESSION_TEST_PASSED;
-
-  Arena arena;
-  char *actual        = nullptr;
-  uint32_t actual_len = 0;
-
-  hpack_huffman_init();
-
-  for (const auto &i : string_test_case) {
-    int len = decode_string(arena, &actual, actual_len, i.encoded_field, i.encoded_field + i.encoded_field_len);
-
-    box.check(len == i.encoded_field_len, "decoded length was %d, expecting %d", len, i.encoded_field_len);
-    box.check(actual_len == i.raw_string_len, "length of decoded string was %d, expecting %d", actual_len, i.raw_string_len);
-    box.check(memcmp(actual, i.raw_string, actual_len) == 0, "decoded string was invalid");
-  }
-}
-
 REGRESSION_TEST(HPACK_DecodeIndexedHeaderField)(RegressionTest *t, int, int *pstatus)
 {
   TestBox box(t, pstatus);
