@@ -27,7 +27,7 @@
  This file implements the LogField object, which is the central
  representation of a logging field.
  ***************************************************************************/
-#include "ts/ink_platform.h"
+#include "tscore/ink_platform.h"
 
 #include "LogUtils.h"
 #include "LogField.h"
@@ -168,7 +168,7 @@ struct cmp_str {
     return ptr_len_casecmp(a._ptr, a._size, b._ptr, b._size) < 0;
   }
 };
-}
+} // namespace
 
 typedef std::map<ts::ConstBuffer, TSMilestonesType, cmp_str> milestone_map;
 static milestone_map m_milestone_map;
@@ -201,6 +201,8 @@ static const milestone milestones[] = {
   {"TS_MILESTONE_SM_FINISH", TS_MILESTONE_SM_FINISH},
   {"TS_MILESTONE_PLUGIN_ACTIVE", TS_MILESTONE_PLUGIN_ACTIVE},
   {"TS_MILESTONE_PLUGIN_TOTAL", TS_MILESTONE_PLUGIN_TOTAL},
+  {"TS_MILESTONE_TLS_HANDSHAKE_START", TS_MILESTONE_TLS_HANDSHAKE_START},
+  {"TS_MILESTONE_TLS_HANDSHAKE_END", TS_MILESTONE_TLS_HANDSHAKE_END},
 };
 
 void
@@ -645,8 +647,9 @@ LogField::update_aggregate(int64_t val)
     return;
   }
 
-  Debug("log-agg", "Aggregate field %s updated with val %" PRId64 ", "
-                   "new val = %" PRId64 ", cnt = %" PRId64 "",
+  Debug("log-agg",
+        "Aggregate field %s updated with val %" PRId64 ", "
+        "new val = %" PRId64 ", cnt = %" PRId64 "",
         m_symbol, val, m_agg_val, m_agg_cnt);
 }
 
@@ -675,9 +678,9 @@ LogField::valid_aggregate_name(char *name)
 }
 
 bool
-LogField::fieldlist_contains_aggregates(char *fieldlist)
+LogField::fieldlist_contains_aggregates(const char *fieldlist)
 {
-  char *match;
+  const char *match;
 
   for (unsigned i = 1; i < countof(aggregate_names); i++) {
     if ((match = strstr(fieldlist, aggregate_names[i])) != nullptr) {
@@ -698,9 +701,7 @@ LogField::fieldlist_contains_aggregates(char *fieldlist)
   heap with "new" and that each element is on at most ONE list.  To enforce
   this, items are copied by default, using the copy ctor.
   -------------------------------------------------------------------------*/
-LogFieldList::LogFieldList() : m_marshal_len(0)
-{
-}
+LogFieldList::LogFieldList() : m_marshal_len(0) {}
 
 LogFieldList::~LogFieldList()
 {
@@ -772,7 +773,9 @@ LogFieldList::marshal_len(LogAccess *lad)
   int bytes = 0;
   for (LogField *f = first(); f; f = next(f)) {
     if (f->type() != LogField::sINT) {
-      bytes += f->marshal_len(lad);
+      const int len = f->marshal_len(lad);
+      ink_release_assert(len >= INK_MIN_ALIGN);
+      bytes += len;
     }
   }
   return m_marshal_len + bytes;
